==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/redhatopenshift/kotlin/inputs/WorkerProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.redhatopenshift.kotlin.inputs

import com.pulumi.azurenative.redhatopenshift.inputs.WorkerProfileArgs.builder
import com.pulumi.azurenative.redhatopenshift.kotlin.enums.EncryptionAtHost
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * WorkerProfile represents a worker profile.
 * @property count The number of worker VMs.
 * @property diskEncryptionSetId The resource ID of an associated DiskEncryptionSet, if applicable.
 * @property diskSizeGB The disk size of the worker VMs.
 * @property encryptionAtHost Whether master virtual machines are encrypted at host.
 * @property name The worker profile name.
 * @property subnetId The Azure resource ID of the worker subnet.
 * @property vmSize The size of the worker VMs.
 */
public data class WorkerProfileArgs(
    public val count: Output<Int>? = null,
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskSizeGB: Output<Int>? = null,
    public val encryptionAtHost: Output<Either<String, EncryptionAtHost>>? = null,
    public val name: Output<String>? = null,
    public val subnetId: Output<String>? = null,
    public val vmSize: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.redhatopenshift.inputs.WorkerProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.redhatopenshift.inputs.WorkerProfileArgs =
        com.pulumi.azurenative.redhatopenshift.inputs.WorkerProfileArgs.builder()
            .count(count?.applyValue({ args0 -> args0 }))
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskSizeGB(diskSizeGB?.applyValue({ args0 -> args0 }))
            .encryptionAtHost(
                encryptionAtHost?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .subnetId(subnetId?.applyValue({ args0 -> args0 }))
            .vmSize(vmSize?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkerProfileArgs].
 */
@PulumiTagMarker
public class WorkerProfileArgsBuilder internal constructor() {
    private var count: Output<Int>? = null

    private var diskEncryptionSetId: Output<String>? = null

    private var diskSizeGB: Output<Int>? = null

    private var encryptionAtHost: Output<Either<String, EncryptionAtHost>>? = null

    private var name: Output<String>? = null

    private var subnetId: Output<String>? = null

    private var vmSize: Output<String>? = null

    /**
     * @param value The number of worker VMs.
     */
    @JvmName("bqsbdahkmevxpdcj")
    public suspend fun count(`value`: Output<Int>) {
        this.count = value
    }

    /**
     * @param value The resource ID of an associated DiskEncryptionSet, if applicable.
     */
    @JvmName("obyeoeuamaqkymdj")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The disk size of the worker VMs.
     */
    @JvmName("vptrkjowcmfpqjlw")
    public suspend fun diskSizeGB(`value`: Output<Int>) {
        this.diskSizeGB = value
    }

    /**
     * @param value Whether master virtual machines are encrypted at host.
     */
    @JvmName("appieivyrmyjtyvp")
    public suspend fun encryptionAtHost(`value`: Output<Either<String, EncryptionAtHost>>) {
        this.encryptionAtHost = value
    }

    /**
     * @param value The worker profile name.
     */
    @JvmName("wropeuobbhfpxcmd")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The Azure resource ID of the worker subnet.
     */
    @JvmName("cdchkifbfplsekrx")
    public suspend fun subnetId(`value`: Output<String>) {
        this.subnetId = value
    }

    /**
     * @param value The size of the worker VMs.
     */
    @JvmName("wqgnluvpeuhwfesg")
    public suspend fun vmSize(`value`: Output<String>) {
        this.vmSize = value
    }

    /**
     * @param value The number of worker VMs.
     */
    @JvmName("ssudnuaeumlbuwqy")
    public suspend fun count(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.count = mapped
    }

    /**
     * @param value The resource ID of an associated DiskEncryptionSet, if applicable.
     */
    @JvmName("olauckykhqaqgbeh")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The disk size of the worker VMs.
     */
    @JvmName("uckbeegecdblmejb")
    public suspend fun diskSizeGB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskSizeGB = mapped
    }

    /**
     * @param value Whether master virtual machines are encrypted at host.
     */
    @JvmName("tnoxsblxtdciovvf")
    public suspend fun encryptionAtHost(`value`: Either<String, EncryptionAtHost>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptionAtHost = mapped
    }

    /**
     * @param value Whether master virtual machines are encrypted at host.
     */
    @JvmName("yvigwygkcwcwfcfp")
    public fun encryptionAtHost(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EncryptionAtHost>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.encryptionAtHost = mapped
    }

    /**
     * @param value Whether master virtual machines are encrypted at host.
     */
    @JvmName("kfougxcmsnnncwib")
    public fun encryptionAtHost(`value`: EncryptionAtHost) {
        val toBeMapped = Either.ofRight<String, EncryptionAtHost>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.encryptionAtHost = mapped
    }

    /**
     * @param value The worker profile name.
     */
    @JvmName("fpulmtrutumkgtwi")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The Azure resource ID of the worker subnet.
     */
    @JvmName("hqfkigufdhegjgqv")
    public suspend fun subnetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetId = mapped
    }

    /**
     * @param value The size of the worker VMs.
     */
    @JvmName("vrxrqtteghtemyfv")
    public suspend fun vmSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmSize = mapped
    }

    internal fun build(): WorkerProfileArgs = WorkerProfileArgs(
        count = count,
        diskEncryptionSetId = diskEncryptionSetId,
        diskSizeGB = diskSizeGB,
        encryptionAtHost = encryptionAtHost,
        name = name,
        subnetId = subnetId,
        vmSize = vmSize,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/redhatopenshift/kotlin/inputs/WorkerProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.redhatopenshift.kotlin.inputs

import com.pulumi.azurenative.redhatopenshift.inputs.WorkerProfileArgs.builder
import com.pulumi.azurenative.redhatopenshift.kotlin.enums.EncryptionAtHost
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * WorkerProfile represents a worker profile.
 * @property count The number of worker VMs.
 * @property diskEncryptionSetId The resource ID of an associated DiskEncryptionSet, if applicable.
 * @property diskSizeGB The disk size of the worker VMs.
 * @property encryptionAtHost Whether master virtual machines are encrypted at host.
 * @property name The worker profile name.
 * @property subnetId The Azure resource ID of the worker subnet.
 * @property vmSize The size of the worker VMs.
 */
public data class WorkerProfileArgs(
    public val count: Output<Int>? = null,
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskSizeGB: Output<Int>? = null,
    public val encryptionAtHost: Output<Either<String, EncryptionAtHost>>? = null,
    public val name: Output<String>? = null,
    public val subnetId: Output<String>? = null,
    public val vmSize: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.redhatopenshift.inputs.WorkerProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.redhatopenshift.inputs.WorkerProfileArgs =
        com.pulumi.azurenative.redhatopenshift.inputs.WorkerProfileArgs.builder()
            .count(count?.applyValue({ args0 -> args0 }))
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskSizeGB(diskSizeGB?.applyValue({ args0 -> args0 }))
            .encryptionAtHost(
                encryptionAtHost?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .subnetId(subnetId?.applyValue({ args0 -> args0 }))
            .vmSize(vmSize?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkerProfileArgs].
 */
@PulumiTagMarker
public class WorkerProfileArgsBuilder internal constructor() {
    private var count: Output<Int>? = null

    private var diskEncryptionSetId: Output<String>? = null

    private var diskSizeGB: Output<Int>? = null

    private var encryptionAtHost: Output<Either<String, EncryptionAtHost>>? = null

    private var name: Output<String>? = null

    private var subnetId: Output<String>? = null

    private var vmSize: Output<String>? = null

    /**
     * @param value The number of worker VMs.
     */
    @JvmName("xqvxcpcsxievmbto")
    public suspend fun count(`value`: Output<Int>) {
        this.count = value
    }

    /**
     * @param value The resource ID of an associated DiskEncryptionSet, if applicable.
     */
    @JvmName("flxfwxplcelxbwbl")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The disk size of the worker VMs.
     */
    @JvmName("gnaaamktqjqtimvj")
    public suspend fun diskSizeGB(`value`: Output<Int>) {
        this.diskSizeGB = value
    }

    /**
     * @param value Whether master virtual machines are encrypted at host.
     */
    @JvmName("dshgakgkvvprlpij")
    public suspend fun encryptionAtHost(`value`: Output<Either<String, EncryptionAtHost>>) {
        this.encryptionAtHost = value
    }

    /**
     * @param value The worker profile name.
     */
    @JvmName("hkhmcbnwmnyxhdgs")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The Azure resource ID of the worker subnet.
     */
    @JvmName("gqelbapmxxccfpxd")
    public suspend fun subnetId(`value`: Output<String>) {
        this.subnetId = value
    }

    /**
     * @param value The size of the worker VMs.
     */
    @JvmName("sjhbwtxtubkvslbu")
    public suspend fun vmSize(`value`: Output<String>) {
        this.vmSize = value
    }

    /**
     * @param value The number of worker VMs.
     */
    @JvmName("mxhxnqxktreprjao")
    public suspend fun count(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.count = mapped
    }

    /**
     * @param value The resource ID of an associated DiskEncryptionSet, if applicable.
     */
    @JvmName("mchiqmrskcsoegll")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The disk size of the worker VMs.
     */
    @JvmName("yecprlbtytvbrqfo")
    public suspend fun diskSizeGB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskSizeGB = mapped
    }

    /**
     * @param value Whether master virtual machines are encrypted at host.
     */
    @JvmName("uawcvkcrnmvutmeg")
    public suspend fun encryptionAtHost(`value`: Either<String, EncryptionAtHost>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptionAtHost = mapped
    }

    /**
     * @param value Whether master virtual machines are encrypted at host.
     */
    @JvmName("xgnmsuvfurhinspc")
    public fun encryptionAtHost(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EncryptionAtHost>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.encryptionAtHost = mapped
    }

    /**
     * @param value Whether master virtual machines are encrypted at host.
     */
    @JvmName("mxufqjymbmcaqtgn")
    public fun encryptionAtHost(`value`: EncryptionAtHost) {
        val toBeMapped = Either.ofRight<String, EncryptionAtHost>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.encryptionAtHost = mapped
    }

    /**
     * @param value The worker profile name.
     */
    @JvmName("wdxadqcbofbnfhmd")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The Azure resource ID of the worker subnet.
     */
    @JvmName("cgtqioqyynswvqnr")
    public suspend fun subnetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetId = mapped
    }

    /**
     * @param value The size of the worker VMs.
     */
    @JvmName("tosvxnduborcbbrm")
    public suspend fun vmSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmSize = mapped
    }

    internal fun build(): WorkerProfileArgs = WorkerProfileArgs(
        count = count,
        diskEncryptionSetId = diskEncryptionSetId,
        diskSizeGB = diskSizeGB,
        encryptionAtHost = encryptionAtHost,
        name = name,
        subnetId = subnetId,
        vmSize = vmSize,
    )
}
